package javax.swing.colorchooser;

import java.awt.Dimension;
import java.awt.Insets;
import java.awt.Container;
import java.awt.Component;
import java.io.Serializable;
import java.awt.LayoutManager;

class SmartGridLayout implements LayoutManager, Serializable
{
    int rows;
    int columns;
    int xGap;
    int yGap;
    int componentCount;
    Component[][] layoutGrid;
    
    public SmartGridLayout(int columns, int rows) {
        this.rows = 2;
        this.columns = 2;
        this.xGap = 2;
        this.yGap = 2;
        this.componentCount = 0;
        this.rows = rows;
        this.columns = columns;
        this.layoutGrid = new Component[columns][rows];
    }
    
    @Override
    public void layoutContainer(Container container) {
        this.buildLayoutGrid(container);
        int[] array = new int[this.rows];
        int[] array2 = new int[this.columns];
        for (int i = 0; i < this.rows; ++i) {
            array[i] = this.computeRowHeight(i);
        }
        for (int j = 0; j < this.columns; ++j) {
            array2[j] = this.computeColumnWidth(j);
        }
        Insets insets = container.getInsets();
        if (container.getComponentOrientation().isLeftToRight()) {
            for (int left = insets.left, n2 = 0; n2 < this.columns; left += array2[n2] + this.xGap, ++n2) {
                for (int top2 = insets.top, n3 = 0; n3 < this.rows; top2 += array[n3] + this.yGap, ++n3) {
                    this.layoutGrid[n2][n3].setBounds(left, top2, array2[n2], array[n3]);
                }
            }
        }
        else {
            int n = container.getWidth() - insets.right;
            int x;
            for (int k = 0; k < this.columns; n = x - this.xGap, ++k) {
                int top = insets.top;
                x = n - array2[k];
                for (int l = 0; l < this.rows; top += array[l] + this.yGap, ++l) {
                    this.layoutGrid[k][l].setBounds(x, top, array2[k], array[l]);
                }
            }
        }
    }
    
    @Override
    public Dimension minimumLayoutSize(Container container) {
        this.buildLayoutGrid(container);
        Insets insets = container.getInsets();
        int n = 0;
        int n2 = 0;
        for (int i = 0; i < this.rows; ++i) {
            n += this.computeRowHeight(i);
        }
        for (int j = 0; j < this.columns; ++j) {
            n2 += this.computeColumnWidth(j);
        }
        return new Dimension(n2 + (this.xGap * (this.columns - 1) + insets.right + insets.left), n + (this.yGap * (this.rows - 1) + insets.top + insets.bottom));
    }
    
    @Override
    public Dimension preferredLayoutSize(Container container) {
        return this.minimumLayoutSize(container);
    }
    
    @Override
    public void addLayoutComponent(String s, Component component) {
    }
    
    @Override
    public void removeLayoutComponent(Component component) {
    }
    
    private void buildLayoutGrid(Container container) {
        Component[] components = container.getComponents();
        int n;
        int n2;
        for (int i = 0; i < components.length; this.layoutGrid[n2][n] = components[i], ++i) {
            n = 0;
            n2 = 0;
            if (i != 0) {
                n2 = i % this.columns;
                n = (i - n2) / this.columns;
            }
        }
    }
    
    private int computeColumnWidth(int n) {
        int n2 = 1;
        for (int i = 0; i < this.rows; ++i) {
            int width = this.layoutGrid[n][i].getPreferredSize().width;
            if (width > n2) {
                n2 = width;
            }
        }
        return n2;
    }
    
    private int computeRowHeight(int n) {
        int n2 = 1;
        for (int i = 0; i < this.columns; ++i) {
            int height = this.layoutGrid[i][n].getPreferredSize().height;
            if (height > n2) {
                n2 = height;
            }
        }
        return n2;
    }
}
